
// File: index.xml

// File: classAlphaScan.xml
%feature("docstring") AlphaScan "

Scan type with inclination angles as coordinate values and a unique wavelength. Features footprint correction.

C++ includes: AlphaScan.h
";

%feature("docstring")  AlphaScan::AlphaScan "AlphaScan::AlphaScan(double wl, std::vector< double > inc_angle)
AlphaScan::AlphaScan";

%feature("docstring")  AlphaScan::AlphaScan "AlphaScan::AlphaScan(double wl, const IAxis &inc_angle)
AlphaScan::AlphaScan";

%feature("docstring")  AlphaScan::AlphaScan "AlphaScan::AlphaScan(double wl, int nbins, double alpha_i_min, double alpha_i_max)
AlphaScan::AlphaScan
Sets angle-defined specular scan. The first parameter is always a wavelength in nm. Second parameter is either a numpy array of incident angles in radians or an IAxis object with angle values. Alternatively an axis can be defined in-place, then the second passed parameter is the number of bins, third - minimum on-axis angle value, fourth - maximum on-axis angle value. 
";

%feature("docstring")  AlphaScan::~AlphaScan "AlphaScan::~AlphaScan() override
AlphaScan::~AlphaScan";

%feature("docstring")  AlphaScan::clone "AlphaScan * AlphaScan::clone() const override
AlphaScan::clone";

%feature("docstring")  AlphaScan::generateElements "std::vector< SpecularElement > AlphaScan::generateElements() const override
AlphaScan::generateElements
Generates simulation elements for specular simulations. 
";

%feature("docstring")  AlphaScan::coordinateAxis "const IAxis * AlphaScan::coordinateAxis() const override
AlphaScan::coordinateAxis
Returns coordinate axis assigned to the data holder. 
";

%feature("docstring")  AlphaScan::footprintFactor "const IFootprintFactor * AlphaScan::footprintFactor() const override
AlphaScan::footprintFactor
Returns IFootprintFactor object pointer. 
";

%feature("docstring")  AlphaScan::footprint "std::vector< double > AlphaScan::footprint(size_t start, size_t n_elements) const override
AlphaScan::footprint
Returns footprint correction factor for a range of simulation elements of size  n_elements and starting from element with index  i. 
";

%feature("docstring")  AlphaScan::numberOfElements "size_t AlphaScan::numberOfElements() const override
AlphaScan::numberOfElements
Returns the number of simulation elements. 
";

%feature("docstring")  AlphaScan::createCoordSystem "CoordSystem1D * AlphaScan::createCoordSystem() const override
AlphaScan::createCoordSystem";

%feature("docstring")  AlphaScan::createIntensities "std::vector< double > AlphaScan::createIntensities(const std::vector< SpecularElement > &eles) const override
AlphaScan::createIntensities
Returns intensity vector corresponding to convolution of given simulation elements. 
";

%feature("docstring")  AlphaScan::wavelengthResolution "const ScanResolution * AlphaScan::wavelengthResolution() const
AlphaScan::wavelengthResolution";

%feature("docstring")  AlphaScan::angleResolution "const ScanResolution * AlphaScan::angleResolution() const
AlphaScan::angleResolution";

%feature("docstring")  AlphaScan::wavelength "double AlphaScan::wavelength() const override
AlphaScan::wavelength";

%feature("docstring")  AlphaScan::setFootprintFactor "void AlphaScan::setFootprintFactor(const IFootprintFactor *f_factor)
AlphaScan::setFootprintFactor
Sets footprint correction factor. 
";

%feature("docstring")  AlphaScan::setWavelengthResolution "void AlphaScan::setWavelengthResolution(const ScanResolution &resolution)
AlphaScan::setWavelengthResolution
Sets wavelength resolution values via  ScanResolution object. 
";

%feature("docstring")  AlphaScan::setRelativeWavelengthResolution "void AlphaScan::setRelativeWavelengthResolution(const IRangedDistribution &distr, double rel_dev)
AlphaScan::setRelativeWavelengthResolution";

%feature("docstring")  AlphaScan::setRelativeWavelengthResolution "void AlphaScan::setRelativeWavelengthResolution(const IRangedDistribution &distr, const std::vector< double > &rel_dev)
AlphaScan::setRelativeWavelengthResolution
Sets wavelength resolution values via IRangedDistribution and values of relative deviations (that is,  rel_dev equals standard deviation divided by the mean value).  rel_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";

%feature("docstring")  AlphaScan::setAbsoluteWavelengthResolution "void AlphaScan::setAbsoluteWavelengthResolution(const IRangedDistribution &distr, double std_dev)
AlphaScan::setAbsoluteWavelengthResolution";

%feature("docstring")  AlphaScan::setAbsoluteWavelengthResolution "void AlphaScan::setAbsoluteWavelengthResolution(const IRangedDistribution &distr, const std::vector< double > &std_dev)
AlphaScan::setAbsoluteWavelengthResolution
Sets wavelength resolution values via IRangedDistribution and values of standard deviations.  std_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";

%feature("docstring")  AlphaScan::setAngleResolution "void AlphaScan::setAngleResolution(const ScanResolution &resolution)
AlphaScan::setAngleResolution
Sets angle resolution values via  ScanResolution object. 
";

%feature("docstring")  AlphaScan::setRelativeAngularResolution "void AlphaScan::setRelativeAngularResolution(const IRangedDistribution &distr, double rel_dev)
AlphaScan::setRelativeAngularResolution";

%feature("docstring")  AlphaScan::setRelativeAngularResolution "void AlphaScan::setRelativeAngularResolution(const IRangedDistribution &distr, const std::vector< double > &rel_dev)
AlphaScan::setRelativeAngularResolution
Sets angular resolution values via IRangedDistribution and values of relative deviations (that is,  rel_dev equals standard deviation divided by the mean value).  rel_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";

%feature("docstring")  AlphaScan::setAbsoluteAngularResolution "void AlphaScan::setAbsoluteAngularResolution(const IRangedDistribution &distr, double std_dev)
AlphaScan::setAbsoluteAngularResolution";

%feature("docstring")  AlphaScan::setAbsoluteAngularResolution "void AlphaScan::setAbsoluteAngularResolution(const IRangedDistribution &distr, const std::vector< double > &std_dev)
AlphaScan::setAbsoluteAngularResolution
Sets angular resolution values via IRangedDistribution and values of standard deviations.  std_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the inclination angle axis. 
";


// File: classChiModuleWrapper.xml
%feature("docstring") ChiModuleWrapper "

Metric wrapper for back-compaptibility with old scripts. 
";

%feature("docstring")  ChiModuleWrapper::ChiModuleWrapper "ChiModuleWrapper::ChiModuleWrapper(std::unique_ptr< IChiSquaredModule > module)
ChiModuleWrapper::ChiModuleWrapper";

%feature("docstring")  ChiModuleWrapper::compute "double ChiModuleWrapper::compute(const std::vector< SimDataPair > &fit_objects, size_t n_pars) const override
ChiModuleWrapper::compute";


// File: classChiSquaredModule.xml
%feature("docstring") ChiSquaredModule "

Calculation of chi2 between two data sets.

C++ includes: ChiSquaredModule.h
";

%feature("docstring")  ChiSquaredModule::ChiSquaredModule "ChiSquaredModule::ChiSquaredModule()=default
ChiSquaredModule::ChiSquaredModule";

%feature("docstring")  ChiSquaredModule::ChiSquaredModule "ChiSquaredModule::ChiSquaredModule(const ChiSquaredModule &other)=default
ChiSquaredModule::ChiSquaredModule";

%feature("docstring")  ChiSquaredModule::~ChiSquaredModule "ChiSquaredModule::~ChiSquaredModule() override=default
ChiSquaredModule::~ChiSquaredModule";

%feature("docstring")  ChiSquaredModule::clone "ChiSquaredModule * ChiSquaredModule::clone() const override
ChiSquaredModule::clone
clone method 
";

%feature("docstring")  ChiSquaredModule::residual "double ChiSquaredModule::residual(double a, double b, double weight) override
ChiSquaredModule::residual";


// File: classConstantBackground.xml
%feature("docstring") ConstantBackground "

Constant background, to be added to simulated scattering.

C++ includes: ConstantBackground.h
";

%feature("docstring")  ConstantBackground::ConstantBackground "ConstantBackground::ConstantBackground(std::vector< double > P)
ConstantBackground::ConstantBackground";

%feature("docstring")  ConstantBackground::ConstantBackground "ConstantBackground::ConstantBackground(double background_value)
ConstantBackground::ConstantBackground";

%feature("docstring")  ConstantBackground::clone "ConstantBackground * ConstantBackground::clone() const override
ConstantBackground::clone";

%feature("docstring")  ConstantBackground::className "std::string ConstantBackground::className() const final
ConstantBackground::className";

%feature("docstring")  ConstantBackground::parDefs "std::vector< ParaMeta > ConstantBackground::parDefs() const final
ConstantBackground::parDefs";

%feature("docstring")  ConstantBackground::backgroundValue "double ConstantBackground::backgroundValue() const
ConstantBackground::backgroundValue";

%feature("docstring")  ConstantBackground::addBackground "double ConstantBackground::addBackground(double intensity) const override
ConstantBackground::addBackground";

%feature("docstring")  ConstantBackground::validate "std::string ConstantBackground::validate() const override
ConstantBackground::validate";


// File: classDepthProbeSimulation.xml
%feature("docstring") DepthProbeSimulation "

Simulation of radiation depth profile.

Holds an instrument and sample model. Computes radiation intensity as function of incoming glancing angle and penetration depth. Scattered rays are neglected. Only refraction, reflection and attenuation of the incoming beam are accounted for.

C++ includes: DepthProbeSimulation.h
";

%feature("docstring")  DepthProbeSimulation::DepthProbeSimulation "DepthProbeSimulation::DepthProbeSimulation(const MultiLayer &sample)
DepthProbeSimulation::DepthProbeSimulation";

%feature("docstring")  DepthProbeSimulation::~DepthProbeSimulation "DepthProbeSimulation::~DepthProbeSimulation() override
DepthProbeSimulation::~DepthProbeSimulation";

%feature("docstring")  DepthProbeSimulation::className "std::string DepthProbeSimulation::className() const final
DepthProbeSimulation::className";

%feature("docstring")  DepthProbeSimulation::nodeChildren "std::vector< const INode * > DepthProbeSimulation::nodeChildren() const override
DepthProbeSimulation::nodeChildren";

%feature("docstring")  DepthProbeSimulation::setBeamParameters "void DepthProbeSimulation::setBeamParameters(double lambda, int nbins, double alpha_i_min, double alpha_i_max, const IFootprintFactor *beam_shape=nullptr)
DepthProbeSimulation::setBeamParameters
Sets beam parameters with alpha_i of the beam defined in the range. 
";

%feature("docstring")  DepthProbeSimulation::setZSpan "void DepthProbeSimulation::setZSpan(size_t n_bins, double z_min, double z_max)
DepthProbeSimulation::setZSpan
Set z positions for intensity calculations. Negative z's correspond to the area under sample surface. The more negative z is, the deeper layer corresponds to it. 
";

%feature("docstring")  DepthProbeSimulation::alphaAxis "const IAxis * DepthProbeSimulation::alphaAxis() const
DepthProbeSimulation::alphaAxis
Returns a pointer to incident angle axis. 
";

%feature("docstring")  DepthProbeSimulation::zAxis "const IAxis * DepthProbeSimulation::zAxis() const
DepthProbeSimulation::zAxis
Returns a pointer to z-position axis. 
";

%feature("docstring")  DepthProbeSimulation::force_polarized "bool DepthProbeSimulation::force_polarized() const override
DepthProbeSimulation::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  DepthProbeSimulation::initDistributionHandler "void DepthProbeSimulation::initDistributionHandler() override
DepthProbeSimulation::initDistributionHandler
init callbacks for setting the parameter values 
";

%feature("docstring")  DepthProbeSimulation::beam "Beam & DepthProbeSimulation::beam()
DepthProbeSimulation::beam";

%feature("docstring")  DepthProbeSimulation::beam "const Beam & DepthProbeSimulation::beam() const
DepthProbeSimulation::beam";

%feature("docstring")  DepthProbeSimulation::createCoordSystem "const ICoordSystem * DepthProbeSimulation::createCoordSystem() const override
DepthProbeSimulation::createCoordSystem";


// File: classIBackground.xml
%feature("docstring") IBackground "

Abstract base class for background noise, to be added to simulated scattering.

Base class of  ConstantBackground,  PoissonBackground.

C++ includes: IBackground.h
";

%feature("docstring")  IBackground::IBackground "IBackground::IBackground(const std::vector< double > &PValues)
IBackground::IBackground";

%feature("docstring")  IBackground::~IBackground "IBackground::~IBackground() override
IBackground::~IBackground";

%feature("docstring")  IBackground::clone "IBackground * IBackground::clone() const override=0
IBackground::clone";

%feature("docstring")  IBackground::addBackground "virtual double IBackground::addBackground(double element) const =0
IBackground::addBackground";


// File: classIChiSquaredModule.xml
%feature("docstring") IChiSquaredModule "

Interface residual calculations.

C++ includes: IChiSquaredModule.h
";

%feature("docstring")  IChiSquaredModule::IChiSquaredModule "IChiSquaredModule::IChiSquaredModule()
IChiSquaredModule::IChiSquaredModule";

%feature("docstring")  IChiSquaredModule::~IChiSquaredModule "IChiSquaredModule::~IChiSquaredModule() override
IChiSquaredModule::~IChiSquaredModule";

%feature("docstring")  IChiSquaredModule::clone "IChiSquaredModule * IChiSquaredModule::clone() const override=0
IChiSquaredModule::clone
clone method 
";

%feature("docstring")  IChiSquaredModule::varianceFunction "const IVarianceFunction * IChiSquaredModule::varianceFunction() const
IChiSquaredModule::varianceFunction
Returns squared function. 
";

%feature("docstring")  IChiSquaredModule::setVarianceFunction "void IChiSquaredModule::setVarianceFunction(const IVarianceFunction &variance_function)
IChiSquaredModule::setVarianceFunction
Sets squared function. 
";

%feature("docstring")  IChiSquaredModule::getIntensityFunction "const IIntensityFunction * IChiSquaredModule::getIntensityFunction() const
IChiSquaredModule::getIntensityFunction
Returns data rescaler. 
";

%feature("docstring")  IChiSquaredModule::setIntensityFunction "void IChiSquaredModule::setIntensityFunction(const IIntensityFunction &intensity_function)
IChiSquaredModule::setIntensityFunction
Sets data rescaler. 
";

%feature("docstring")  IChiSquaredModule::residual "virtual double IChiSquaredModule::residual(double a, double b, double weight)=0
IChiSquaredModule::residual";


// File: classIIntensityFunction.xml
%feature("docstring") IIntensityFunction "

Interface for applying arbitrary function to the measured intensity.

C++ includes: IIntensityFunction.h
";

%feature("docstring")  IIntensityFunction::~IIntensityFunction "IIntensityFunction::~IIntensityFunction()
IIntensityFunction::~IIntensityFunction";

%feature("docstring")  IIntensityFunction::clone "virtual IIntensityFunction * IIntensityFunction::clone() const =0
IIntensityFunction::clone";

%feature("docstring")  IIntensityFunction::evaluate "virtual double IIntensityFunction::evaluate(double value) const =0
IIntensityFunction::evaluate";


// File: classIMetricWrapper.xml
%feature("docstring") IMetricWrapper "";

%feature("docstring")  IMetricWrapper::~IMetricWrapper "virtual IMetricWrapper::~IMetricWrapper()=default
IMetricWrapper::~IMetricWrapper";

%feature("docstring")  IMetricWrapper::compute "virtual double IMetricWrapper::compute(const std::vector< SimDataPair > &fit_objects, size_t n_pars) const =0
IMetricWrapper::compute";


// File: classIntensityFunctionLog.xml
%feature("docstring") IntensityFunctionLog "

Algorithm for applying log function to the measured intensity.

C++ includes: IIntensityFunction.h
";

%feature("docstring")  IntensityFunctionLog::clone "IntensityFunctionLog * IntensityFunctionLog::clone() const override
IntensityFunctionLog::clone";

%feature("docstring")  IntensityFunctionLog::evaluate "double IntensityFunctionLog::evaluate(double value) const override
IntensityFunctionLog::evaluate";


// File: classIntensityFunctionSqrt.xml
%feature("docstring") IntensityFunctionSqrt "

Algorithm for applying sqrt function to the measured intensity.

C++ includes: IIntensityFunction.h
";

%feature("docstring")  IntensityFunctionSqrt::clone "IntensityFunctionSqrt * IntensityFunctionSqrt::clone() const override
IntensityFunctionSqrt::clone";

%feature("docstring")  IntensityFunctionSqrt::evaluate "double IntensityFunctionSqrt::evaluate(double value) const override
IntensityFunctionSqrt::evaluate";


// File: classISimulation.xml
%feature("docstring") ISimulation "

Abstract base class, holds the infrastructure to run a simulation.

Base class of  SpecularSimulation,  ISimulation2D and  DepthProbeSimulation.

Holds an instrument and sample model. Provides the common infrastructure to run a simulation: multithreading, batch processing, averaging over parameter distributions, etc.

Simulations are run, and results returned, by the function  ISimulation::simulate().

C++ includes: ISimulation.h
";

%feature("docstring")  ISimulation::ISimulation "ISimulation::ISimulation(const MultiLayer &sample)
ISimulation::ISimulation";

%feature("docstring")  ISimulation::~ISimulation "ISimulation::~ISimulation() override
ISimulation::~ISimulation";

%feature("docstring")  ISimulation::ISimulation "ISimulation::ISimulation(const ISimulation &)=delete
ISimulation::ISimulation";

%feature("docstring")  ISimulation::ISimulation "ISimulation::ISimulation(ISimulation &&)=default
ISimulation::ISimulation";

%feature("docstring")  ISimulation::simulate "SimulationResult ISimulation::simulate()
ISimulation::simulate
Run a simulation, and return the result.

Runs simulation with possible averaging over parameter distributions; returns result. 
";

%feature("docstring")  ISimulation::setBackground "void ISimulation::setBackground(const IBackground &bg)
ISimulation::setBackground";

%feature("docstring")  ISimulation::addParameterDistribution "void ISimulation::addParameterDistribution(ParameterDistribution::WhichParameter whichParameter, const IDistribution1D &distribution, size_t nbr_samples, double sigma_factor=0.0, const RealLimits &limits=RealLimits())
ISimulation::addParameterDistribution";

%feature("docstring")  ISimulation::addParameterDistribution "void ISimulation::addParameterDistribution(const ParameterDistribution &par_distr)
ISimulation::addParameterDistribution";

%feature("docstring")  ISimulation::options "const SimulationOptions & ISimulation::options() const
ISimulation::options";

%feature("docstring")  ISimulation::options "SimulationOptions & ISimulation::options()
ISimulation::options";

%feature("docstring")  ISimulation::setTerminalProgressMonitor "void ISimulation::setTerminalProgressMonitor()
ISimulation::setTerminalProgressMonitor
Initializes a progress monitor that prints to stdout. 
";

%feature("docstring")  ISimulation::force_polarized "virtual bool ISimulation::force_polarized() const =0
ISimulation::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  ISimulation::subscribe "void ISimulation::subscribe(const std::function< bool(size_t)> &inform)
ISimulation::subscribe";

%feature("docstring")  ISimulation::unitOfParameter "std::string ISimulation::unitOfParameter(ParameterDistribution::WhichParameter which) const
ISimulation::unitOfParameter";

%feature("docstring")  ISimulation::sample "const MultiLayer * ISimulation::sample() const
ISimulation::sample";

%feature("docstring")  ISimulation::background "const IBackground * ISimulation::background() const
ISimulation::background";

%feature("docstring")  ISimulation::getDistributions "const std::vector< ParameterDistribution > & ISimulation::getDistributions() const
ISimulation::getDistributions";

%feature("docstring")  ISimulation::nodeChildren "std::vector< const INode * > ISimulation::nodeChildren() const override
ISimulation::nodeChildren";

%feature("docstring")  ISimulation::createCoordSystem "virtual const ICoordSystem * ISimulation::createCoordSystem() const =0
ISimulation::createCoordSystem";


// File: classISimulation2D.xml
%feature("docstring") ISimulation2D "

Abstract base class of simulations that generate 2D patterns.

Base class of  OffspecSimulation and  ScatteringSimulation.

Holds the common implementations for simulations with a 2D detector.

C++ includes: ISimulation2D.h
";

%feature("docstring")  ISimulation2D::ISimulation2D "ISimulation2D::ISimulation2D(const Beam &beam, const MultiLayer &sample, const IDetector &detector)
ISimulation2D::ISimulation2D";

%feature("docstring")  ISimulation2D::ISimulation2D "ISimulation2D::ISimulation2D(const MultiLayer &sample)
ISimulation2D::ISimulation2D";

%feature("docstring")  ISimulation2D::~ISimulation2D "ISimulation2D::~ISimulation2D() override
ISimulation2D::~ISimulation2D";

%feature("docstring")  ISimulation2D::nodeChildren "std::vector< const INode * > ISimulation2D::nodeChildren() const override
ISimulation2D::nodeChildren";

%feature("docstring")  ISimulation2D::force_polarized "bool ISimulation2D::force_polarized() const override
ISimulation2D::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  ISimulation2D::addMask "void ISimulation2D::addMask(const IShape2D &shape, bool mask_value=true)
ISimulation2D::addMask
Adds mask of given shape to the stack of detector masks. The mask value 'true' means that the channel will be excluded from the simulation. The mask which is added last has priority.

Parameters:
-----------

shape: 
The shape of mask (Rectangle, Polygon, Line, Ellipse)

mask_value: 
The value of mask 
";

%feature("docstring")  ISimulation2D::maskAll "void ISimulation2D::maskAll()
ISimulation2D::maskAll
Put the mask for all detector channels (i.e. exclude whole detector from the analysis) 
";

%feature("docstring")  ISimulation2D::setRegionOfInterest "void ISimulation2D::setRegionOfInterest(double xlow, double ylow, double xup, double yup)
ISimulation2D::setRegionOfInterest
Sets rectangular region of interest with lower left and upper right corners defined. 
";

%feature("docstring")  ISimulation2D::beam "Beam & ISimulation2D::beam()
ISimulation2D::beam";

%feature("docstring")  ISimulation2D::detector "IDetector & ISimulation2D::detector()
ISimulation2D::detector";

%feature("docstring")  ISimulation2D::beam "const Beam & ISimulation2D::beam() const
ISimulation2D::beam";

%feature("docstring")  ISimulation2D::detector "const IDetector & ISimulation2D::detector() const
ISimulation2D::detector";

%feature("docstring")  ISimulation2D::getDetector "const IDetector * ISimulation2D::getDetector() const
ISimulation2D::getDetector";


// File: classIterationInfo.xml
%feature("docstring") IterationInfo "

Stores fit iteration info to track fit flow from various observers. Used in context of FitObjective.

C++ includes: IterationInfo.h
";

%feature("docstring")  IterationInfo::IterationInfo "IterationInfo::IterationInfo()
IterationInfo::IterationInfo";

%feature("docstring")  IterationInfo::update "void IterationInfo::update(const mumufit::Parameters &params, double chi2)
IterationInfo::update";

%feature("docstring")  IterationInfo::iterationCount "unsigned IterationInfo::iterationCount() const
IterationInfo::iterationCount
Returns current number of minimizer iterations. 
";

%feature("docstring")  IterationInfo::chi2 "double IterationInfo::chi2() const
IterationInfo::chi2";

%feature("docstring")  IterationInfo::parameters "mumufit::Parameters IterationInfo::parameters() const
IterationInfo::parameters";

%feature("docstring")  IterationInfo::parameterMap "std::map< std::string, double > IterationInfo::parameterMap() const
IterationInfo::parameterMap
Returns map of fit parameter names and its current values. 
";


// File: classObjectiveMetricWrapper.xml
%feature("docstring") ObjectiveMetricWrapper "";

%feature("docstring")  ObjectiveMetricWrapper::ObjectiveMetricWrapper "ObjectiveMetricWrapper::ObjectiveMetricWrapper(std::unique_ptr< ObjectiveMetric > module)
ObjectiveMetricWrapper::ObjectiveMetricWrapper";

%feature("docstring")  ObjectiveMetricWrapper::compute "double ObjectiveMetricWrapper::compute(const std::vector< SimDataPair > &fit_objects, size_t n_pars) const override
ObjectiveMetricWrapper::compute";


// File: classOffspecSimulation.xml
%feature("docstring") OffspecSimulation "

Off-specular scattering simulation.

Holds an instrument and sample model. Computes reflected and scattered intensity as function of incident and final glancing angle.

C++ includes: OffspecSimulation.h
";

%feature("docstring")  OffspecSimulation::OffspecSimulation "OffspecSimulation::OffspecSimulation(const Beam &beam, const MultiLayer &sample, const IDetector &detector)
OffspecSimulation::OffspecSimulation";

%feature("docstring")  OffspecSimulation::OffspecSimulation "OffspecSimulation::OffspecSimulation(const MultiLayer &sample)
OffspecSimulation::OffspecSimulation";

%feature("docstring")  OffspecSimulation::~OffspecSimulation "OffspecSimulation::~OffspecSimulation() override=default
OffspecSimulation::~OffspecSimulation";

%feature("docstring")  OffspecSimulation::className "std::string OffspecSimulation::className() const final
OffspecSimulation::className";

%feature("docstring")  OffspecSimulation::setBeamParameters "void OffspecSimulation::setBeamParameters(double wavelength, const IAxis &alpha_axis, double phi_i)
OffspecSimulation::setBeamParameters
Sets beam parameters from here (forwarded to Instrument) 
";

%feature("docstring")  OffspecSimulation::beamAxis "const IAxis * OffspecSimulation::beamAxis() const
OffspecSimulation::beamAxis
Returns axis of the beam. 
";

%feature("docstring")  OffspecSimulation::createCoordSystem "const ICoordSystem * OffspecSimulation::createCoordSystem() const override
OffspecSimulation::createCoordSystem";


// File: classPoissonBackground.xml
%feature("docstring") PoissonBackground "

Poisson distributed noise, to be added to simulated scattering.

C++ includes: PoissonBackground.h
";

%feature("docstring")  PoissonBackground::PoissonBackground "PoissonBackground::PoissonBackground()
PoissonBackground::PoissonBackground";

%feature("docstring")  PoissonBackground::clone "PoissonBackground * PoissonBackground::clone() const override
PoissonBackground::clone";

%feature("docstring")  PoissonBackground::className "std::string PoissonBackground::className() const final
PoissonBackground::className";

%feature("docstring")  PoissonBackground::addBackground "double PoissonBackground::addBackground(double intensity) const override
PoissonBackground::addBackground";


// File: classPyBuilderCallback.xml
%feature("docstring") PyBuilderCallback "

Builds simulation object using a Python callable. Base class to wrap Python callable and pass it to C++. Used in swig interface file, intended to be overloaded from Python.

C++ includes: PyFittingCallbacks.h
";

%feature("docstring")  PyBuilderCallback::PyBuilderCallback "PyBuilderCallback::PyBuilderCallback()
PyBuilderCallback::PyBuilderCallback";

%feature("docstring")  PyBuilderCallback::~PyBuilderCallback "PyBuilderCallback::~PyBuilderCallback()
PyBuilderCallback::~PyBuilderCallback";

%feature("docstring")  PyBuilderCallback::build_simulation "ISimulation * PyBuilderCallback::build_simulation(const mumufit::Parameters &) const
PyBuilderCallback::build_simulation";


// File: classPyObserverCallback.xml
%feature("docstring") PyObserverCallback "

Observer for FitObjective based on Python callable. Base class to wrap Python callable and pass it to C++. Used in swig interface file, intended to be overloaded from Python.

C++ includes: PyFittingCallbacks.h
";

%feature("docstring")  PyObserverCallback::PyObserverCallback "PyObserverCallback::PyObserverCallback()
PyObserverCallback::PyObserverCallback";

%feature("docstring")  PyObserverCallback::~PyObserverCallback "PyObserverCallback::~PyObserverCallback()
PyObserverCallback::~PyObserverCallback";

%feature("docstring")  PyObserverCallback::update "void PyObserverCallback::update(const FitObjective &)
PyObserverCallback::update";


// File: classQzScan.xml
%feature("docstring") QzScan "

Scan type with z-components of scattering vector as coordinate values. Wavelength and incident angles are not accessible separately.

C++ includes: QzScan.h
";

%feature("docstring")  QzScan::QzScan "QzScan::QzScan(std::vector< double > qs_nm)
QzScan::QzScan
Accepts qz-value vector (in inverse nm) 
";

%feature("docstring")  QzScan::QzScan "QzScan::QzScan(const IAxis &qs_nm)
QzScan::QzScan";

%feature("docstring")  QzScan::QzScan "QzScan::QzScan(int nbins, double qz_min, double qz_max)
QzScan::QzScan
Sets q-defined specular scan. Accepts either numpy array of q-values sorted in ascending order or an IAxis object with q-values. Alternatively an axis can be defined in-place, then the first passed parameter is the number of bins, second - minimum on-axis q-value, third - maximum on-axis q_value. 
";

%feature("docstring")  QzScan::~QzScan "QzScan::~QzScan() override
QzScan::~QzScan";

%feature("docstring")  QzScan::clone "QzScan * QzScan::clone() const override
QzScan::clone";

%feature("docstring")  QzScan::resolution "const ScanResolution * QzScan::resolution() const
QzScan::resolution";

%feature("docstring")  QzScan::wavelength "double QzScan::wavelength() const override
QzScan::wavelength";

%feature("docstring")  QzScan::generateElements "std::vector< SpecularElement > QzScan::generateElements() const override
QzScan::generateElements
Generates simulation elements for specular simulations. 
";

%feature("docstring")  QzScan::coordinateAxis "const IAxis * QzScan::coordinateAxis() const override
QzScan::coordinateAxis
Returns coordinate axis assigned to the data holder. 
";

%feature("docstring")  QzScan::footprintFactor "const IFootprintFactor * QzScan::footprintFactor() const override
QzScan::footprintFactor
Returns IFootprintFactor object pointer. 
";

%feature("docstring")  QzScan::footprint "std::vector< double > QzScan::footprint(size_t i, size_t n_elements) const override
QzScan::footprint
Returns footprint correction factor for a range of simulation elements of size  n_elements and starting from element with index  i. 
";

%feature("docstring")  QzScan::numberOfElements "size_t QzScan::numberOfElements() const override
QzScan::numberOfElements
Returns the number of simulation elements. 
";

%feature("docstring")  QzScan::createCoordSystem "CoordSystem1D * QzScan::createCoordSystem() const override
QzScan::createCoordSystem";

%feature("docstring")  QzScan::createIntensities "std::vector< double > QzScan::createIntensities(const std::vector< SpecularElement > &eles) const override
QzScan::createIntensities
Returns intensity vector corresponding to convolution of given simulation elements. 
";

%feature("docstring")  QzScan::setQResolution "void QzScan::setQResolution(const ScanResolution &resolution)
QzScan::setQResolution
Sets q resolution values via  ScanResolution object. 
";

%feature("docstring")  QzScan::setRelativeQResolution "void QzScan::setRelativeQResolution(const IRangedDistribution &distr, double rel_dev)
QzScan::setRelativeQResolution";

%feature("docstring")  QzScan::setRelativeQResolution "void QzScan::setRelativeQResolution(const IRangedDistribution &distr, const std::vector< double > &rel_dev)
QzScan::setRelativeQResolution
Sets qz resolution values via IRangedDistribution and values of relative deviations (that is,  rel_dev equals standard deviation divided by the mean value).  rel_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the qz-axis. 
";

%feature("docstring")  QzScan::setAbsoluteQResolution "void QzScan::setAbsoluteQResolution(const IRangedDistribution &distr, double std_dev)
QzScan::setAbsoluteQResolution";

%feature("docstring")  QzScan::setAbsoluteQResolution "void QzScan::setAbsoluteQResolution(const IRangedDistribution &distr, const std::vector< double > &std_dev)
QzScan::setAbsoluteQResolution
Sets qz resolution values via IRangedDistribution and values of standard deviations.  std_dev can be either single-valued or a numpy array. In the latter case the length of the array should coinside with the length of the qz-axis. 
";

%feature("docstring")  QzScan::setOffset "void QzScan::setOffset(double offset)
QzScan::setOffset";

%feature("docstring")  QzScan::offset "double QzScan::offset() const
QzScan::offset";


// File: classScanResolution.xml
%feature("docstring") ScanResolution "

Container for reflectivity resolution data.

C++ includes: ScanResolution.h
";

%feature("docstring")  ScanResolution::~ScanResolution "ScanResolution::~ScanResolution() override
ScanResolution::~ScanResolution";

%feature("docstring")  ScanResolution::clone "ScanResolution * ScanResolution::clone() const override=0
ScanResolution::clone";

%feature("docstring")  ScanResolution::distribution "const IRangedDistribution * ScanResolution::distribution() const
ScanResolution::distribution";

%feature("docstring")  ScanResolution::nSamples "size_t ScanResolution::nSamples() const
ScanResolution::nSamples";

%feature("docstring")  ScanResolution::generateSamples "virtual DistrOutput ScanResolution::generateSamples(double mean, size_t n_times) const =0
ScanResolution::generateSamples";

%feature("docstring")  ScanResolution::generateSamples "virtual DistrOutput ScanResolution::generateSamples(const std::vector< double > &mean) const =0
ScanResolution::generateSamples";

%feature("docstring")  ScanResolution::stdDevs "virtual std::vector< double > ScanResolution::stdDevs(double mean, size_t n_times) const =0
ScanResolution::stdDevs";

%feature("docstring")  ScanResolution::stdDevs "virtual std::vector< double > ScanResolution::stdDevs(const std::vector< double > &mean) const =0
ScanResolution::stdDevs";

%feature("docstring")  ScanResolution::empty "bool ScanResolution::empty() const
ScanResolution::empty";

%feature("docstring")  ScanResolution::name "virtual std::string ScanResolution::name() const =0
ScanResolution::name";

%feature("docstring")  ScanResolution::delta "virtual double ScanResolution::delta() const =0
ScanResolution::delta";


// File: classScatteringSimulation.xml
%feature("docstring") ScatteringSimulation "

GISAS simulation.

Holds an instrument and sample model. Computes the scattered intensity as function of 2D detector coordinates.

C++ includes: ScatteringSimulation.h
";

%feature("docstring")  ScatteringSimulation::ScatteringSimulation "ScatteringSimulation::ScatteringSimulation(const Beam &beam, const MultiLayer &sample, const IDetector &detector)
ScatteringSimulation::ScatteringSimulation";

%feature("docstring")  ScatteringSimulation::~ScatteringSimulation "ScatteringSimulation::~ScatteringSimulation() override=default
ScatteringSimulation::~ScatteringSimulation";

%feature("docstring")  ScatteringSimulation::className "std::string ScatteringSimulation::className() const final
ScatteringSimulation::className";

%feature("docstring")  ScatteringSimulation::createCoordSystem "const ICoordSystem * ScatteringSimulation::createCoordSystem() const override
ScatteringSimulation::createCoordSystem";


// File: classSpecularSimulation.xml
%feature("docstring") SpecularSimulation "

Specular reflectometry simulation.

Holds an instrument and sample model. Computes detected intensity as function of the glancing angles alpha_i=alpha_f.

C++ includes: SpecularSimulation.h
";

%feature("docstring")  SpecularSimulation::SpecularSimulation "SpecularSimulation::SpecularSimulation(const ISpecularScan &scan, const MultiLayer &sample)
SpecularSimulation::SpecularSimulation";

%feature("docstring")  SpecularSimulation::~SpecularSimulation "SpecularSimulation::~SpecularSimulation() override
SpecularSimulation::~SpecularSimulation";

%feature("docstring")  SpecularSimulation::SpecularSimulation "SpecularSimulation::SpecularSimulation(SpecularSimulation &&)
SpecularSimulation::SpecularSimulation";

%feature("docstring")  SpecularSimulation::className "std::string SpecularSimulation::className() const final
SpecularSimulation::className";

%feature("docstring")  SpecularSimulation::force_polarized "bool SpecularSimulation::force_polarized() const override
SpecularSimulation::force_polarized
Force polarized computation even in absence of sample magnetization or external fields. 
";

%feature("docstring")  SpecularSimulation::prepareSimulation "void SpecularSimulation::prepareSimulation() override
SpecularSimulation::prepareSimulation
Put into a clean state for running a simulation. 
";

%feature("docstring")  SpecularSimulation::createCoordSystem "const ICoordSystem * SpecularSimulation::createCoordSystem() const override
SpecularSimulation::createCoordSystem";

%feature("docstring")  SpecularSimulation::scan "const ISpecularScan * SpecularSimulation::scan() const
SpecularSimulation::scan
Returns internal data handler. 
";


// File: classVarianceConstantFunction.xml
%feature("docstring") VarianceConstantFunction "

Returns 1.0 as variance value

C++ includes: VarianceFunctions.h
";

%feature("docstring")  VarianceConstantFunction::clone "VarianceConstantFunction * VarianceConstantFunction::clone() const override
VarianceConstantFunction::clone";

%feature("docstring")  VarianceConstantFunction::variance "double VarianceConstantFunction::variance(double, double) const override
VarianceConstantFunction::variance";


// File: classVarianceSimFunction.xml
%feature("docstring") VarianceSimFunction "

Returns max(sim, epsilon)

C++ includes: VarianceFunctions.h
";

%feature("docstring")  VarianceSimFunction::VarianceSimFunction "VarianceSimFunction::VarianceSimFunction(double epsilon=1.0)
VarianceSimFunction::VarianceSimFunction";

%feature("docstring")  VarianceSimFunction::clone "VarianceSimFunction * VarianceSimFunction::clone() const override
VarianceSimFunction::clone";

%feature("docstring")  VarianceSimFunction::variance "double VarianceSimFunction::variance(double exp, double sim) const override
VarianceSimFunction::variance";


// File: namespace_0d17.xml


// File: namespace_0d19.xml


// File: namespace_0d31.xml


// File: namespace_0d33.xml


// File: namespace_0d35.xml


// File: namespace_0d38.xml


// File: namespace_0d45.xml


// File: namespace_0d47.xml


// File: namespace_0d51.xml


// File: namespace_0d61.xml


// File: namespace_0d67.xml


// File: namespace_0d69.xml


// File: namespace_0d72.xml


// File: namespace_0d9.xml


// File: namespacePy.xml


// File: namespacePy_1_1Export.xml
%feature("docstring")  Py::Export::sampleCode "std::string Py::Export::sampleCode(const MultiLayer &sample)
Py::Export::sampleCode";

%feature("docstring")  Py::Export::simulationPlotCode "std::string Py::Export::simulationPlotCode(const ISimulation &simulation)
Py::Export::simulationPlotCode";

%feature("docstring")  Py::Export::simulationSaveCode "std::string Py::Export::simulationSaveCode(const ISimulation &simulation, const std::string &fname)
Py::Export::simulationSaveCode";


// File: namespacePy_1_1Fmt.xml
%feature("docstring")  Py::Fmt::printRealLimits "std::string Py::Fmt::printRealLimits(const RealLimits &limits, const std::string &units)
Py::Fmt::printRealLimits";

%feature("docstring")  Py::Fmt::printRealLimitsArg "std::string Py::Fmt::printRealLimitsArg(const RealLimits &limits, const std::string &units)
Py::Fmt::printRealLimitsArg
Prints RealLimits in the form of argument (in the context of ParameterDistribution and similar). Default RealLimits will not be printed, any other will be printed as \", ba.RealLimits.limited(1*deg, 2*deg)\" 
";


// File: namespacePy_1_1Fmt2.xml
%feature("docstring")  Py::Fmt2::representShape2D "std::string Py::Fmt2::representShape2D(const std::string &indent, const IShape2D *ishape, bool mask_value, std::function< std::string(double)> printValueFunc)
Py::Fmt2::representShape2D
Returns fixed Python code snippet that defines the function \"simulate\". 
";

%feature("docstring")  Py::Fmt2::printAxis "std::string Py::Fmt2::printAxis(const IAxis *axis, const std::string &unit)
Py::Fmt2::printAxis
Prints an axis. 
";

%feature("docstring")  Py::Fmt2::printParameterDistribution "std::string Py::Fmt2::printParameterDistribution(const ParameterDistribution &par_distr, const std::string &distVarName, const std::string &units)
Py::Fmt2::printParameterDistribution";

%feature("docstring")  Py::Fmt2::printRangedDistribution "std::string Py::Fmt2::printRangedDistribution(const IRangedDistribution &distr)
Py::Fmt2::printRangedDistribution";


// File: ConstantBackground_8cpp.xml


// File: ConstantBackground_8h.xml


// File: IBackground_8cpp.xml


// File: IBackground_8h.xml


// File: PoissonBackground_8cpp.xml


// File: PoissonBackground_8h.xml


// File: ComputationStatus_8h.xml


// File: DepthProbeComputation_8cpp.xml


// File: DepthProbeComputation_8h.xml


// File: DWBAComputation_8cpp.xml


// File: DWBAComputation_8h.xml


// File: IComputation_8cpp.xml


// File: IComputation_8h.xml


// File: SpecularComputation_8cpp.xml


// File: SpecularComputation_8h.xml


// File: GISASSpecularContribution_8cpp.xml


// File: GISASSpecularContribution_8h.xml


// File: ParticleLayoutContribution_8cpp.xml


// File: ParticleLayoutContribution_8h.xml


// File: RoughMultiLayerContribution_8cpp.xml


// File: RoughMultiLayerContribution_8h.xml


// File: ComponentKeyHandler_8cpp.xml


// File: ComponentKeyHandler_8h.xml


// File: ExportToPython_8cpp.xml


// File: ExportToPython_8h.xml


// File: MaterialKeyHandler_8cpp.xml


// File: MaterialKeyHandler_8h.xml


// File: PyFmt2_8cpp.xml


// File: PyFmt2_8h.xml


// File: PyFmtLimits_8cpp.xml


// File: PyFmtLimits_8h.xml


// File: SampleToPython_8cpp.xml


// File: SampleToPython_8h.xml


// File: SimulationToPython_8cpp.xml


// File: SimulationToPython_8h.xml


// File: FitObjective_8cpp.xml


// File: FitObjective_8h.xml


// File: FitObserver_8h.xml


// File: FitPrintService_8cpp.xml


// File: FitPrintService_8h.xml


// File: FitStatus_8cpp.xml


// File: FitStatus_8h.xml


// File: FitTypes_8h.xml


// File: IterationInfo_8cpp.xml


// File: IterationInfo_8h.xml


// File: ObjectiveMetric_8cpp.xml


// File: ObjectiveMetric_8h.xml


// File: ObjectiveMetricUtils_8cpp.xml


// File: ObjectiveMetricUtils_8h.xml


// File: PyFittingCallbacks_8cpp.xml


// File: PyFittingCallbacks_8h.xml


// File: SimDataPair_8cpp.xml


// File: SimDataPair_8h.xml


// File: ChiSquaredModule_8cpp.xml


// File: ChiSquaredModule_8h.xml


// File: IChiSquaredModule_8cpp.xml


// File: IChiSquaredModule_8h.xml


// File: IIntensityFunction_8cpp.xml


// File: IIntensityFunction_8h.xml


// File: VarianceFunctions_8cpp.xml


// File: VarianceFunctions_8h.xml


// File: AlphaScan_8cpp.xml


// File: AlphaScan_8h.xml


// File: ISpecularScan_8cpp.xml


// File: ISpecularScan_8h.xml


// File: QzScan_8cpp.xml


// File: QzScan_8h.xml


// File: ScanResolution_8cpp.xml


// File: ScanResolution_8h.xml


// File: DepthProbeSimulation_8cpp.xml


// File: DepthProbeSimulation_8h.xml


// File: includeSimulations_8h.xml


// File: ISimulation_8cpp.xml


// File: ISimulation_8h.xml


// File: ISimulation2D_8cpp.xml


// File: ISimulation2D_8h.xml


// File: OffspecSimulation_8cpp.xml


// File: OffspecSimulation_8h.xml


// File: ScatteringSimulation_8cpp.xml


// File: ScatteringSimulation_8h.xml


// File: SpecularSimulation_8cpp.xml


// File: SpecularSimulation_8h.xml


// File: dir_69622bdd5740149fae063934074f5b46.xml


// File: dir_80b5fc9f893426fd5fb9fe1745a013f9.xml


// File: dir_84c420b536327f5f78c313c975fc3e9e.xml


// File: dir_2f33233fd7f1d04aa5b1f43b1305dab7.xml


// File: dir_cf99511bd3a2a600b8765d13a2b8e763.xml


// File: dir_a7a79cf6fe55455f4aa40bf75f4a8347.xml


// File: dir_b1fb6e3aebde3102cfb6ed4db3ad7376.xml


// File: dir_45c35af18c2a9ebb0bbd91b9bd7680de.xml


// File: dir_4d66887e6a4aee2bb3ce63737017e0ad.xml

